/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2006 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.engine.orchestra;

import java.util.logging.Level;

import javax.jbi.JBIException;

import org.jbpm.env.EnvironmentFactory;
import org.ow2.orchestra.env.DefaultEnvXMLGenerator;
import org.ow2.orchestra.execution.services.itf.Invoker;
import org.ow2.orchestra.execution.services.itf.Publisher;
import org.ow2.orchestra.execution.services.itf.Repository;
import org.ow2.orchestra.execution.services.memory.MemoryRepository;
import org.ow2.petals.component.framework.se.AbstractServiceEngine;
import org.ow2.petals.engine.orchestra.jbi.JBIInvoker;
import org.ow2.petals.engine.orchestra.jbi.JBIPublisher;

/**
 * The Orchestra Service Engine component class.
 * 
 * @author Nicolas SALATGE - eBM WebSourcing
 * 
 */
public class OrchestraEngine extends AbstractServiceEngine {

    /**
     * the orchestra service
     */
    private OrchestraService orchestra;

    /**
     * the environment Factory
     */
    private EnvironmentFactory environmentFactory;

    /**
     * The default constructor
     * 
     */
    public OrchestraEngine() {
        super();
    }

    /**
     * initialize the component
     * 
     * @throws JBIException
     *             impossible to iniliaze the compoenent
     */
    @Override
    protected final void doInit() throws JBIException {
        super.doInit();

        this.getLogger().log(Level.INFO, "Orchestra Intialization...");

        //  Create the jbi environment for orchestra
        this.environmentFactory = this.createEnvironmentFactory();

        // Creation of Orchestra Manager
        final OrchestraSUManager suManager = new OrchestraSUManager();

        // set service unit listener
        final OrchestraSUListener suListener = new OrchestraSUListener(suManager,
                this.environmentFactory, this.getLogger());
        this.setServiceUnitListener(suListener);

        // Creation of orchestra service
        this.orchestra = new OrchestraServiceImpl(suManager, this.getLogger());
    }

    /**
     * Get the orchestra service
     * 
     * @return the orchestra service
     */
    public final OrchestraService getOrchestra() {
        return this.orchestra;
    }

    /**
     * Create a JBI environment for orchestra
     * 
     * @return the jbi environment
     */
    public final EnvironmentFactory createEnvironmentFactory() {
        final DefaultEnvXMLGenerator envGenerator = new DefaultEnvXMLGenerator();
        envGenerator.setApplicationEntry(Publisher.DEFAULT_KEY, JBIPublisher.class);
        envGenerator.setApplicationEntry(Repository.DEFAULT_KEY, MemoryRepository.class);
        // envGenerator.setEntry(Receiver.DEFAULT_KEY, JBIReceiver.class);
        envGenerator.setApplicationEntry(Invoker.DEFAULT_KEY, JBIInvoker.class);

        final EnvironmentFactory environmentFac = envGenerator.createEnvironmentFactory();
        return environmentFac;
    }

}
