/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2006 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.engine.orchestra;

import java.util.HashMap;
import java.util.Map;

/**
 * This class implements the orchestra su manager
 * 
 * @author Nicolas SALATGE - eBMWebSourcing
 * 
 */
public class OrchestraSUManager {

    /**
     * Map containing all su with thier BPEL context.
     */
    private final Map<String, BPELContext> su;

    /**
     * Default constructor
     * 
     */
    public OrchestraSUManager() {
        this.su = new HashMap<String, BPELContext>();
    }

    /**
     * Add a bpel context to the map
     * 
     * @param endpointName
     *            the endpointName
     * @param bpel
     *            the bpel context
     */
    public final void add(final String endpointName, final BPELContext bpel) {
        this.su.put(endpointName, bpel);
    }

    /**
     * Get a bpel context
     * 
     * @param endpointName
     *            the endpointName
     * @return the Bpel context
     */
    public final BPELContext get(final String endpointName) {
        return this.su.get(endpointName);
    }

    /**
     * Remove a bpel context
     * 
     * @param endpointName
     *            the endpointName
     * @return the Bpel context
     */
    public final BPELContext remove(final String endpointName) {
        return this.su.remove(endpointName);
    }

}
