/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2006 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.engine.orchestra;

import java.util.logging.Logger;

import javax.jbi.messaging.MessagingException;
import javax.wsdl.WSDLException;

import org.ow2.petals.component.framework.util.Exchange;
import org.ow2.petals.engine.orchestra.listener.JBIListener;

/**
 * This class implements the orchestra services provides by this service engine
 *
 * @author Nicolas SALATGE - eBMWebSourcing
 *
 */
public class OrchestraServiceImpl implements OrchestraService {

    /**
     * The Logger
     */
    private final Logger logger;

    /**
     * SU Manager
     */
    private final OrchestraSUManager suManager;

    /**
     * Creates a new instance of OrchestraServiceImpl
     *
     * @param suManager
     *            the su manager
     * @param logger
     *            the logger
     */
    public OrchestraServiceImpl(final OrchestraSUManager suManager, final Logger logger) {
        super();
        this.logger = logger;
        this.suManager = suManager;
    }

    /**
     * Launch the BpelProcess.
     *
     * @param msg
     *            The message exchange
     * @param listener
     *            The listener
     * @throws MessagingException
     *             Impossible to launch the process
     * @throws OrchestraException
     *             Impossible to realize this method
     */
    public final void launchProcess(final Exchange msg, final JBIListener listener)
        throws MessagingException, OrchestraException {
        this.logger.info("Start the process on " + msg.getEndpoint().getEndpointName());
        final BPELContext bpelContext = this.suManager.get(msg.getEndpoint().getEndpointName());
        this.logger.info("Ready to launch the BPEL process");
        try {
            bpelContext.launchBPELProcess(msg, listener);
        } catch (final WSDLException e) {
            throw new MessagingException(e);
        }
        this.logger.info("Launching of the BPEL process is done");
    }

}
